pub mod event_handler;
pub mod state;
#[cfg(test)]
pub mod test;
pub mod tui;
pub mod utility;
pub mod widgets;

use crossterm::{cursor, event, event::KeyCode, terminal, ExecutableCommand};
use ratatui::{
    backend::CrosstermBackend,
    layout::{Constraint, Direction, Layout},
    widgets::{Block, Borders, List, ListItem},
    Terminal,
};
use state::ApplicationState;
use std::{env, error::Error, io};
use tui::run;

fn main() -> Result<(), Box<dyn Error>> {
    // Get the number of columns from command-line arguments
    let args: Vec<String> = env::args().collect();
    let num_columns: usize = if args.len() > 1 {
        args[1].parse()?
    } else {
        // Default to 3 columns if no argument is passed
        3
    };

    // Initialize application state
    let mut app_state = ApplicationState::new(num_columns);
    run(&mut app_state)?;
    // Clean up terminal state
    terminal::disable_raw_mode()?;
    Ok(())
}
